@@ -8,7 +8,7 @@
 #################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '0.3-4'
+Version = '0.4-1'
 
 import os
 import sys
@@ -76,7 +76,7 @@ def doUpdateConfig():
        
 ##############################################################
 
-class SwappolubeAbout(QMainWindow):
+class SwappolubeAbout(QtGui.QMainWindow):
     '''About Window'''
     def __init__(self, parent=None):
         QMainWindow.__init__(self,parent)
@@ -88,7 +88,7 @@ class SwappolubeAbout(QMainWindow):
         aboutScrollArea = QScrollArea(self)
         aboutScrollArea.setWidgetResizable(True)
         awidget = QWidget(aboutScrollArea)
-        awidget.setMinimumSize(480,1000)
+        awidget.setMinimumSize(470,1000)
         awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
         aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
         #Kinetic scroller is available on Maemo and should be on meego
@@ -167,6 +167,9 @@ class MyMainWindow(QtGui.QMainWindow):
              QtGui.QWidget.__init__(self, parent)
              self.ui = Ui_swappolube()
              self.ui.setupUi(self)
+             #new code
+             self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+             self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
              
              ##Connect the GUI Buttons with actions
                ##Create Settings
@@ -187,7 +190,9 @@ class MyMainWindow(QtGui.QMainWindow):
         ##Create Methods
                 
         def doAbout(self):
-          self.aboutWin = SwappolubeAbout(self)
+             stackwindow =SwappolubeAbout(self)
+             stackwindow.show()
+             ##self.aboutWin = SwappolubeAbout(self)
 
         def doDeleteTunings(self):
              os.system('sudo %supdateTuning deleteTuning' % AppPath)
@@ -219,8 +224,7 @@ class MyMainWindow(QtGui.QMainWindow):
              os.system('sudo %supdateTuning VFSCachePressure 100' % AppPath )
              
              if CheckFile(MainPath, MainFile) == True:
-                message = 'The default values have been restored to the system.\
-                           \n\nWARNING: A tuning file exists and will reapply its settings on the next reboot.'
+                message = 'The default values have been restored to the system.\n\nWARNING: A tuning file exists and will reapply its settings on the next reboot.'
              else:   
                 message = 'The default values have been restored to the system.'
              showMessage(message)
@@ -370,9 +374,8 @@ class MyMainWindow(QtGui.QMainWindow):
              if self.ui.radioVFSCachePressure.isChecked() == True:
                os.system('sudo %supdateTuning VFSCachePressure %s' % (AppPath, VFSCachePressure) )
 
-             message = 'The new configuration has been applied to the system.\
-                        These settings will be changed back to its defaults on the next reboot.\
-                        \n\nIf you want them to persist use the "Store" button.'
+             message = 'The new values have been applied to the system.\n\nINFO:They will revert to their defaults on the next reboot.\
+                        \nIf you want them to persist use the Store button.'
              showMessage(message)
              
         def doCreateConfig(self):
